package de.ozgcloud.eingang.xta;

import java.util.stream.Stream;

import jakarta.xml.bind.JAXBElement;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import eu.osci.ws._2008._05.transport.MsgStatusListType;
import eu.osci.ws._2014._10.transport.MessageMetaData;

@Mapper
interface XtaMessageMetaDataMapper {

	@Mapping(target = "messageTypeListVersion", ignore = true)
	@Mapping(target = "metaDataFile", ignore = true)
	@Mapping(target = "service", ignore = true)
	@Mapping(target = "origin", source = "deliveryAttributes.origin")
	@Mapping(target = "delivery", source = "deliveryAttributes.delivery")
	@Mapping(target = "messageId", source = "msgIdentification.messageID.value")
	@Mapping(target = "messageType", source = "qualifier.messageType.code")
	@Mapping(target = "xtaIdentifier", source = "destinations.reader.identifier.value")
	XtaMessageMetaData fromSoap(MessageMetaData metaData);

	default XtaMessageId fromString(String id) {
		return XtaMessageId.from(id);
	}

	@Mapping(target = "moreMessagesAvailable", constant = "false")
	XtaMessageMetaDatasAndHeader msgStatusListFromSoap(MsgStatusListTypeAndHeaderResponse statusList);

	default Stream<XtaMessageMetaData> map(JAXBElement<MsgStatusListType> msgStatusListResponse) {
		return msgStatusListResponse.getValue().getMessageMetaData().stream().map(this::fromSoap);
	}
}
